module JWT.JWKSet exposing (JWKSet, fromString, jwkSetDecoder)

{-|


# JWK

@docs JWKSet, fromString, jwkSetDecoder

-}

import JWT.JWK as JWK exposing (JWK)
import Json.Decode as Decode


{-| A set of JSON Web Keys.
-}
type alias JWKSet =
    { keys : List JWK }


{-| Convenience function to run the jwkSetDecoder on a string.
-}
fromString : String -> Result Decode.Error JWKSet
fromString string =
    Decode.decodeString jwkSetDecoder string


{-| JSON decoder for a JWKSet
-}
jwkSetDecoder : Decode.Decoder JWKSet
jwkSetDecoder =
    Decode.list JWK.decoder
        |> Decode.field "keys"
        |> Decode.map JWKSet
